@@ -6,7 +6,8 @@ import os
 from shutil import copyfile
 import numpy as np
 from Bio import AlignIO, SeqIO, Seq, Align
-from .io import run_shell_command, shquote
+from .io.shell_command_runner import run_shell_command
+from .io.vcf import shquote
 from .utils import nthreads_value
 from collections import defaultdict
 
@@ -336,7 +337,20 @@ def analyse_insertions(aln, ungapped, insertion_csv):
     insertions = [defaultdict(list) for ins in insertion_coords]
     for idx, insertion_coord in enumerate(insertion_coords):
         for seq in aln:
-            s = seq[insertion_coord[0]:insertion_coord[1]].seq.ungap("-").ungap("N").ungap("?")
+            try:
+                # biopython>=1.80 does not have seq.ungap()
+                s = (seq[insertion_coord[0]:insertion_coord[1]].seq
+                    .replace("-", "")
+                    .replace("N", "")
+                    .replace("?", "")
+                )
+            except AttributeError:
+                # biopython<1.79 does not have seq.replace()
+                s = (seq[insertion_coord[0]:insertion_coord[1]].seq
+                    .ungap("-")
+                    .ungap("N")
+                    .ungap("?")
+                )
             if len(s):
                 insertions[idx][str(s)].append(seq.name)
 
